// 模拟后端动态生成路由
import { defineFakeRoute } from "vite-plugin-fake-server/client";
import { system, monitor, permission, profile, list } from "@/router/enums";
import { messageTypes } from "element-plus";
import path from "path";
import { active } from "sortablejs";


/**
 * 路由设置权限是为了双重检查、第一次检查获取路由检查、第二次检查权限检查
 * admin：管理员角色
 * user：学生
 */
const upgradePackageManagerRoute = {
  path: "/upgradePackage",
  redirect: "/upgradePackage/list",
  name: "upgradePackage",
  meta: {
    icon: "ri:list-check",
    title: "升级包管理",
    rank: list
  },
  children: [
    {
      path: "/upgradePackage/list",
      name: "upgradePackageList",
      component: "upgrade-package-management/index.vue",
      meta: {
        icon: "ri:bank-card-line",
        title: "升级包管理",
        showParent: false,
        roles: ["admin"]
      }
    },
    {
      path: "/upgradePackage/list/management/:infor",
      name: "upgradePackageListManagement",
      activePath: "/upgradePackage/list",
      component: "upgrade-package-management/components/packageManager/index.vue",
      meta: {
        title: "升级包内容管理",
        showLink: false,
        roles: ["admin"]
      }
    }
  ]
}

const upgradePackageFeedBackRoute = {
  path: "/upgradePackageFeedBack",
  redirect: "/upgradePackageFeedBack/list",
  meta: {
    icon: "ri:list-check",
    title: "升级包反馈",
    rank: list
  },
  children: [
    {
      path: "/upgradePackageFeedBack/list",
      name: "upgradePackage-feedBack-List",
      component: "upgrade-package-feedback/index.vue",
      meta: {
        icon: "ri:feedback-line",
        title: "升级包反馈",
        showParent: false,
        roles: ["admin"]
      }
    },
    {
      path: "/upgradePackageFeedBack/list/management/:infor",
      name: "upgradePackage-list-feedBack-management",
      activePath: "/upgradePackageFeedBack/list",
      component: "upgrade-package-feedback/feedBackManagement/index.vue",
      meta: {
        title: "升级包反馈管理",
        showLink: false,
        roles: ["admin"]
      }
    },
    {
      path: "/upgradePackageFeedBack/list/page/",
      name: "upgradePackage-list-feedBack-page",
      activePath: "/upgradePackageFeedBack/list",
      component: "upgrade-package-feedback/feedBackPage/index.vue",
      meta: {
        title: "反馈内容",
        showLink: false,
        roles: ["admin","user"]
      }
    }
  ]
}

const showUpgradePackageRoute = {
  path: "/showUpgradePackage",
  meta: {
    icon: "ri:list-check",
    title: "获取升级包",
    rank: list
  },
  children: [
    {
    path: "/showUpgradePackage/list",
    name: "showUpgradePackageList",
    activePath: "/showUpgradePackage",
    component: "user/showUpgradePackage/index.vue",
    meta: {
      title: "获取升级包",
      showParent: false,
      showLink: true,
      roles: ["user"]
    }
  },
   {
    path: "/showUpgradePackage/list/page/:infor",
    name: "showUpgradePackageListPage",
    activePath: "/showUpgradePackage",
    component: "user/showUpgradePackage/components/packageInfo.vue",
    meta: {
      title: "升级包内容",
      showLink: false,
      roles: ["user"]
    }
   } 
  ]
}

















const profileRouter = {
  path: "/profile",
  meta: {
    title: "menus.pureProfile",
    rank: profile,
    showLink: false,
  },
  children: [
    {
      path: "/profile/index",
      component: 'profile/index.vue',
      name: "ProfileInfo",
      meta: {
        title: "menus.pureInfo",
        icon: "ri:account-box-line",
        roles: ["admin", "user"],
      }
    },
  ]
};


const systemManagementRouter = {
  path: "/system",
  meta: {
    icon: "ri:settings-3-line",
    title: "menus.pureSysManagement",
    rank: system
  },
  children: [
    {
      path: "/system/user/index",
      name: "SystemUser",
      meta: {
        icon: "ri:admin-line",
        title: "menus.pureUser",
        roles: ["admin"]
      }
    },
    {
      path: "/system/role/index",
      name: "SystemRole",
      meta: {
        icon: "ri:admin-fill",
        title: "menus.pureRole",
        roles: ["admin"]
      }
    },
    {
      path: "/system/menu/index",
      name: "SystemMenu",
      meta: {
        icon: "ep:menu",
        title: "menus.pureSystemMenu",
        roles: ["admin"]
      }
    },
  ]
};

const systemMonitorRouter = {
  path: "/monitor",
  meta: {
    icon: "ep:monitor",
    title: "menus.pureSysMonitor",
    rank: monitor
  },
  children: [
    {
      path: "/monitor/online-user",
      component: "monitor/online/index",
      name: "OnlineUser",
      meta: {
        icon: "ri:user-voice-line",
        title: "menus.pureOnlineUser",
        roles: ["admin"]
      }
    },
    {
      path: "/monitor/login-logs",
      component: "monitor/logs/login/index",
      name: "LoginLog",
      meta: {
        icon: "ri:window-line",
        title: "menus.pureLoginLog",
        roles: ["admin"]
      }
    },
    {
      path: "/monitor/operation-logs",
      component: "monitor/logs/operation/index",
      name: "OperationLog",
      meta: {
        icon: "ri:history-fill",
        title: "menus.pureOperationLog",
        roles: ["admin"]
      }
    },
    {
      path: "/monitor/system-logs",
      component: "monitor/logs/system/index",
      name: "SystemLog",
      meta: {
        icon: "ri:file-search-line",
        title: "menus.pureSystemLog",
        roles: ["admin"]
      }
    }
  ]
};


export default defineFakeRoute([
  {
    url: "/getRoutes",
    method: "get",
    response: () => {
      return {
        success: true,
        data: [
          systemManagementRouter,
          systemMonitorRouter,
          profileRouter,
          upgradePackageManagerRoute,
          upgradePackageFeedBackRoute,
          showUpgradePackageRoute
        ]
      };
    }
  }
]);
