import { http } from "@/utils/http";
// 升级包总数数据
type packageSummary = {
  // 总数
  value: string;
  // 上升百分比
  percent: string;
  // 折线图数据
  data: Array<number>;
}

type packageSummaryResult = {
  success: boolean;
  data?: packageSummary;
}

/** 获取升级包总数数据 */
export const getPackageSummary = (data?: object) => {
  return http.request<packageSummaryResult>("post", "/get-package-summary", { data });
}

// 用户反馈总数
type feedbackSummary = {
  // 总数
  value: string;
  // 上升百分比
  percent: string;
  // 折线图数据
  data: Array<number>;
}

type feedbackSummaryResult = {
  success: boolean;
  data?: feedbackSummary;
}

/** 获取用户反馈总数数据 */
export const getFeedbackSummary = (data?: object) => {
  return http.request<feedbackSummaryResult>("post", "/get-feedback-summary", { data });
}

// 用户反馈解决数数据
type feedbackSolved = {
  // 总数
  value: string;
  // 上升百分比
  percent: string;
  // 折线图数据
  data: Array<number>;
}

type feedbackSolvedResult = {
  success: boolean;
  data?: feedbackSolved;

}

/** 获取用户反馈解决数数据 */
export const getFeedbackSolved = (data?: object) => {
  return http.request<feedbackSolvedResult>("post", "/get-feedback-solved", { data });
}

// 升级包校验通过率数据
type packagePassRate = {
  // 总数
  value: string;
  // 上升百分比
  percent: string;
  // 折线图数据
  data: Array<number>;
}

type packagePassRateResult = {
  success: boolean;
  data?: packagePassRate;

}

/** 获取升级包校验通过率数据 */
export const getPackagePassRate = (data?: object) => {
  return http.request<packagePassRateResult>("post", "/get-package-pass-rate", { data });
}

// 下载数分析数据
type downloadData = {
  requireData: Array<number>;
  questionData: Array<number>;
}

type downloadDataResult = {
  success: boolean;
  data?:Array<downloadData>;

}

/** 获取下载数分析数据 */
export const getDownloadData = (data?: object) => {
  return http.request<downloadDataResult>("post", "/get-download-data", { data });
}

// 用户成功安装概率数据
type installData = {
  week: string;
  percentage: number;
}

type installDataResult = {
  success: boolean;
  data?: Array<installData>;
}

/** 获取用户成功安装概率数据 */
export const getInstallData = (data?: object) => {
  return http.request<installDataResult>("post", "/get-install-data", { data });
}

// 数据表数据
type tableData = {
  // 升级包表编号
  tableId: number;
  // 升级包表名称
  tableName: string;
  // 升级包表下载数
  tableDownloadNum: number;
  // 升级包表反馈数
  tableFeedBackNum: number;
  // 升级包表反馈解决数
  tableFeedBackSolvedNum: number;
  // 升级包表安装成功数
  tableInstallNum: number;
}

type tableDataResult = {
  success: boolean;
  data?: Array<tableData>;
}

/** 获取数据表数据 */
export const getTableData = (data?: object) => {
  return http.request<tableDataResult>("post", "/get-table-data", { data });
}

// 获取反馈动态数据
type feedbackDynamic = {
  // 反馈动态时间
  date: string;
  // 新增反馈数
  requiredNumber: number;
  // 解决反馈数
  resolvedNumber: number;
}

type feedbackDynamicResult = {
  success: boolean;
  data?: Array<feedbackDynamic>;

}

/** 获取反馈动态数据 */
export const getFeedbackDynamic = (data?: object) => {
  return http.request<feedbackDynamicResult>("post", "/get-feedback-dynamic", { data });
}