import { http } from "@/utils/http";

type Result = {
  success: boolean;
  data?: Array<any>;
};

type ResultTable = {
  success: boolean;
  data?: {
    /** 列表数据 */
    list: Array<any>;
    /** 总条目数 */
    total?: number;
    /** 每页显示条目个数 */
    pageSize?: number;
    /** 当前页数 */
    currentPage?: number;
  };
};

type User = {
  id?: number;
  /** 用于判断是`新增`还是`修改` */
  title: string;
  nickname: string;
  username: string;
  password: string;
  phone: string | number;
  email: string;
  sex: string | number;
  status: number;
  remark: string;
  role: string;
}

type UserResult = {
  success: boolean;
  data?: {
    /** 列表数据 */
    list: Array<User>;
    /** 总条目数 */
    total?: number;
    /** 每页显示条目个数 */
    pageSize?: number;
    /** 当前页数 */
    currentPage?: number;
  };
};

type selectUser = {
    username: string,
    phone: string,
    status: number,
}

/** 获取系统管理-用户管理列表 */
export const getUserList = (data?: selectUser) => {
  return http.request<UserResult>("post", "/user", { data });
};

type UserRole = {
  id: number;
  name: string;
}

type UserRoleResult = {
  success: boolean;
  data?: Array<UserRole>;
};

/** 系统管理-用户管理-获取所有角色列表 */
export const getAllRoleList = () => {
  return http.request<UserRoleResult>("get", "/list-all-role");
};

type UserRoleIdResult = {
  success: boolean;
  data?: Array<number>;
};

/** 系统管理-用户管理-根据userId，获取对应角色id列表（userId：用户id） */
export const getRoleIds = (data?: object) => {
  return http.request<UserRoleIdResult>("post", "/list-role-ids", { data });
};

/** 系统管理-用户管理-添加新的用户 */
export const addNewUser = (data?: User) => {
  return http.request<Result>("post", "/add-user", { data });
 }

/** 系统管理-用户管理-修改用户信息 */
export const alterUserInfo = (data?: User) => { 
  return http.request<Result>("post", "/update-user", { data });
}

/** 系统管理-用户管理-删除用户 */
export const deleteUser = (data?: object) => { 
  return http.request<Result>("post", "/delete-user", { data });
}
type UserPassword = {
  id: number;
  password: string;
}

/** 系统管理-用户管理-修改用户密码 */
export const alterUserPassword = (data?: UserPassword) => {
  return http.request<Result>("post", "/update-password", { data });
}

type UserAssignRole = {
  id: number;
  roleId: Record<number, unknown>[];
}

/** 系统管理-用户管理-分配角色 */
export const assignRole = (data?: UserAssignRole) => { 
  return http.request<Result>("post", "/assign-role", { data });
}




/** 获取系统监控-在线用户列表 */
export const getOnlineLogsList = (data?: object) => {
  return http.request<ResultTable>("post", "/online-logs", { data });
};

/** 获取系统监控-登录日志列表 */
export const getLoginLogsList = (data?: object) => {
  return http.request<ResultTable>("post", "/login-logs", { data });
};

/** 获取系统监控-操作日志列表 */
export const getOperationLogsList = (data?: object) => {
  return http.request<ResultTable>("post", "/operation-logs", { data });
};

/** 获取系统监控-系统日志列表 */
export const getSystemLogsList = (data?: object) => {
  return http.request<ResultTable>("post", "/system-logs", { data });
};

/** 获取系统监控-系统日志-根据 id 查日志详情 */
export const getSystemLogsDetail = (data?: object) => {
  return http.request<Result>("post", "/system-logs-detail", { data });
};

type MenuResult = {
  success: boolean;
  data?: Array<Menu>;
};

type Menu = {
  parentId: number,
  id: number,
  menuType: number,
  title: string,
}

type Role = {
  createTime: Date,
  id: number,
  name: string,
  code: string,
  status: number,
  remark: string,
}

type RoleResult = {
    success: boolean;
    data?: {
    /** 列表数据 */
    list: Array<Role>;
    /** 总条目数 */
    total?: number;
    /** 每页显示条目个数 */
    pageSize?: number;
    /** 当前页数 */
    currentPage?: number;
  };
};


/** 获取角色管理-权限-菜单权限 */
export const getRoleMenu = (data?: object) => {
  return http.request<MenuResult>("post", "/role-menu", { data });
};

/** 
 * @param 用户Id
 * 获取角色管理-权限-菜单权限-根据角色 id 查对应菜单 */
export const getRoleMenuIds = (data?: object) => {
  return http.request<Result>("post", "/role-menu-ids", { data });
};

type selectRole = {
  name: string,
  code: string,
  status: number,
}
/**
 * @param 查询的数据
 *  获取系统管理-角色管理列表 */
export const getRoleList = (data?: selectRole) => {
  return http.request<RoleResult>("post", "/role", { data });
};

type NewRole = {
  id: number,
  name: string,
  code: string,
  remark: string,
  status: number,
}

/** 角色管理-添加角色 */
export const addRole = (data?: NewRole) => {
  return http.request<Result>("post", "/add-role", { data });
};

/** 角色管理-修改角色 */
export const updateRole = (data?: NewRole) => {
  return http.request<Result>("post", "/update-role", { data });
};

/** 角色管理-删除角色 */
export const deleteRole = (data?: Array<number>) => {
  return http.request<Result>("post", "/delete-role", { data });
};