import { http } from "@/utils/http";
import { Skill,Activity,TimeLine } from "@/views/profile/type";

export type UserResult = {
    success: boolean;
  data: {
    /** `token` */
    accessToken: string;
    /** 用于调用刷新`accessToken`的接口时所需的`token` */
    refreshToken: string;
    /** `accessToken`的过期时间（格式'xxxx/xx/xx xx:xx:xx'） */
    expires: Date;
  };
};

export type RefreshTokenResult = {
  success: boolean;
  data: {
    /** `token` */
    accessToken: string;
    /** 用于调用刷新`accessToken`的接口时所需的`token` */
    refreshToken: string;
    /** `accessToken`的过期时间（格式'xxxx/xx/xx xx:xx:xx'） */
    expires: Date;
  };
};

export type UserInfo = {
  /** 头像 */
  avatar: string;
  /** 职工号、学号 */
  username: string;
  /** 昵称 */
  nickname: string;
  /** 邮箱 */
  email: string;
  /** 联系电话 */
  phone: string;
  /** 用户Id */
  ID: number,
  /** 个人界面背景图片 */
  backgroundImg: string,
  /** 个人介绍 */
  introduction: string,
  /** 权限 */
  roles: string[],
};

export type UserInfoResult = {
  success: boolean;
  data: UserInfo;
};

type ResultTable = {
  success: boolean;
  data?: {
    /** 列表数据 */
    list: Array<any>;
    /** 总条目数 */
    total?: number;
    /** 每页显示条目个数 */
    pageSize?: number;
    /** 当前页数 */
    currentPage?: number;
  };
};

type InfoResult = {
  success: boolean;
  data: {
    skills: Array<Skill>;
    activities: Array<Activity>;
    timeline: Array<TimeLine>;
  };
}

/** 登录 */
export const getLogin = (data?: object) => {
  return http.request<UserResult>("post", "user/login", {data });
};

/** 刷新`token` */
export const refreshTokenApi = (data?: any) => {
  return http.request<RefreshTokenResult>("post", "user/refreshToken", { data } );
};

/** 账户设置-个人信息 */
export const getMine = (data?: string) => {
  return http.request<UserInfoResult>("get", "user/info", { data });
};
// 获取个人主页skills、timeline、activities的接口
export const getActivities = (data?: object) => {
  return http.request<InfoResult>("get", "/user/getSkills", { data });
}
/** 修改个人信息 */
export const updateMine = (data?: object) => { 
  return http.request<UserInfoResult>("post","/updateInfo",{data})
}
/* 用户注册 */
export const register = (data?: object) => { 
  return http.request<UserResult>("post","/user/register",{data})
}
// /** 账户设置-个人安全日志 */
// export const getMineLogs = (data?: object) => {
//   return http.request<ResultTable>("get", "/mine-logs", { data });
// };
