// 密钥，用于签发和验证 JWT
const secretKey = 'your_secret_key';

// 生成 JWT
export const generateToken = (payload: any): Promise<string> => {
  const header = {
    alg: 'HS256',
    typ: 'JWT'
  };

  const encodedHeader = btoa(JSON.stringify(header));
  const encodedPayload = btoa(JSON.stringify(payload));

  const data = encodedHeader + '.' + encodedPayload;

  return signData(data, secretKey).then(signature => {
    console.log(data + '.' + signature)
    return data + '.' + signature;
  });
}

// 验证 JWT
export const verifyToken = (token: string): any => {
  const parts = token.split('.');
  if (parts.length !== 3) {
    console.error('Invalid token format');
    return null;
  }

  const [encodedHeader, encodedPayload, signature] = parts;
  const data = encodedHeader + '.' + encodedPayload;

  return verifyData(data, signature).then(valid => {
    if (!valid) {
      console.error('Invalid signature');
      return null;
    }

    return JSON.parse(atob(encodedPayload));
  });
}

// 使用 Web Crypto API 进行 HMAC SHA256 签名
const signData = (data: string, key: string): Promise<string> => {
  const encoder = new TextEncoder();
  const encodedKey = encoder.encode(key);
  const encodedData = encoder.encode(data);
  console.log(crypto.subtle)

  return crypto.subtle.importKey('raw', encodedKey, { name: 'HMAC', hash: 'SHA-256' }, false, ['sign']).then(key => {
    return crypto.subtle.sign('HMAC', key, encodedData).then(signature => {
      return Array.from(new Uint8Array(signature)).map(byte => String.fromCharCode(byte)).join('');
    });
  });
}

// 验证签名
const verifyData = (data: string, signature: string): Promise<boolean> => {
  const encoder = new TextEncoder();
  const encodedData = encoder.encode(data);
  const encodedSignature = new Uint8Array(signature.split('').map(char => char.charCodeAt(0)));

  return crypto.subtle.importKey('raw', encoder.encode(secretKey), { name: 'HMAC', hash: 'SHA-256' }, false, ['verify']).then(key => {
    return crypto.subtle.verify('HMAC', key, encodedSignature, encodedData);
  });
}