import dayjs from "dayjs";
import editForm from "../form.vue"
import { handleTree } from "@/utils/tree";
import { message } from "@/utils/message";
import { ElMessageBox } from "element-plus";
import { usePublicHooks } from "../hooks";
import { transformI18n } from "@/plugins/i18n";
import { addDialog } from "@/components/ReDialog";
import type { FormItemProps } from "../utils/types";
import type { PaginationProps } from "@pureadmin/table";
import { getKeyList, deviceDetection } from "@pureadmin/utils";
import { getRoleList, getRoleMenu, getRoleMenuIds } from "@/api/system";
import { type Ref, reactive, ref, onMounted, h, toRaw, watch } from "vue";
import feedBack from "mock/feedBack";
import { deleteFeedBacks, getFeedbackList } from "@/api/upgradePackage-feedBack";
import { func } from "vue-types";
import { status } from "nprogress";

export function useRole(treeRef: Ref,tableRef: Ref,) {
  const form = reactive({
    feedBackType: "",
    feedBackTime: "",
    status: "",
  });
  const curRow = ref();
  const formRef = ref();
  const dataList = ref([]);
  const treeIds = ref([]);
  const treeData = ref([]);
  const isShow = ref(false);
  const loading = ref(true);
  const isLinkage = ref(false);
  const treeSearchValue = ref();
  const switchLoadMap = ref({});
  const isExpandAll = ref(false);
  const isSelectAll = ref(false);
   const selectedNum = ref(0);
  const { switchStyle } = usePublicHooks();
  const treeProps = {
    value: "id",
    label: "title",
    children: "children"
  };
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
    const getFeedBackType = (type, text = false) => {
    switch (type) {
      case 1:
        return text ? "版本升级" : "primary";
      case 2:
        return text ? "BUG处理" : "danger";
       case 3:
        return text ? "功能完善" : "success";
       case 4:
        return text ? "提出建议" : "info";
       case 5:
        return text ? "技术支持" : "default";
       case 6:
        return text ? "异常情况" : "warning";
    }
  };
  const columns: TableColumnList = [
  {
      label: "勾选列", // 如果需要表格多选，此处label必须设置
      type: "selection",
      fixed: "left",
      reserveSelection: true // 数据刷新后保留选项
    },
    {
      label: "反馈编号",
      prop: "feedBackId"
    },
    {
      label: "反馈类型",
      prop: "feedBackType",
            cellRenderer: ({ row, props }) => (
        <el-tag
          size={props.size}
          type={getFeedBackType(row.feedBackType,false)}
          effect=""
        >
          {getFeedBackType(row.feedBackType, true)}
        </el-tag>
      )
    },
    {
      label: "反馈标题",
      prop: "feedBackTitle"
    },
    {
      label: "反馈用户",
      prop: "feedBackUser",
      minWidth: 120
    },
    {
      label: "反馈对应升级包",
      prop: "packageName",
      minWidth:120,
    },
    {
      label: "反馈版本",
      prop: "packageVersion",
      minWidth:120,
    },
    {
      label: "反馈时间",
      prop: "feedBackTime",
      minWidth: 120,
      formatter: ({ feedBackTime }) =>
        dayjs(feedBackTime).format("YYYY-MM-DD HH:mm:ss")
    },
    {
      label: "处理状态",
      cellRenderer: scope => (
        <el-switch
          size={scope.props.size === "small" ? "small" : "default"}
          loading={switchLoadMap.value[scope.index]?.loading}
          v-model={scope.row.status}
          active-value={1}
          inactive-value={0}
          active-text="已处理"
          inactive-text="未处理"
          inline-prompt
          style={switchStyle.value}
          onChange={() => onChange(scope as any)}
        />
      ),
      minWidth: 120
    },
    {
      label: "操作",
      fixed: "right",
      width: 210,
      slot: "operation"
    }
  ];


    /** 批量删除 */
  function onbatchDel() {
    // 返回当前选中的行
    const curSelected = tableRef.value.getTableRef().getSelectionRows();
    console.log(curSelected)
    // 接下来根据实际业务，通过选中行的某项数据，比如下面的id，调用接口进行批量删除
    deleteFeedBacks( curSelected).then(res => {
      if (res.success) {
        message(`已删除反馈编号为 ${getKeyList(curSelected, "id")} 的数据`, {
          type: "success"
        });
        tableRef.value.getTableRef().clearSelection();
        onSearch();
      } else {
        message("删除失败", { type: "error" });
      }
    });
  }

  function onChange({ row, index }) {
    ElMessageBox.confirm(
      `确认要<strong>${
        row.status === 0 ? "未处理" : "已处理"
      }</strong><strong style='color:var(--el-color-primary)'>${
        row.feedBackTitle
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    )
      .then(() => {
        switchLoadMap.value[index] = Object.assign(
          {},
          switchLoadMap.value[index],
          {
            loading: true
          }
        );
        setTimeout(() => {
          switchLoadMap.value[index] = Object.assign(
            {},
            switchLoadMap.value[index],
            {
              loading: false
            }
          );
          message(`${row.status === 0 ? "未反馈" : "已反馈"}${row.feedBackTitle}`, {
            type: "success"
          });
        }, 300);
      })
      .catch(() => {
        row.status === 0 ? (row.status = 1) : (row.status = 0);
      });
  }

  function handleDelete(row) { 
    ElMessageBox.confirm("确定要删除该条反馈吗？",{
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
    }).then(() => {
      console.log(row)
       })

  }

  function handleSizeChange(val: number) {
    console.log(`${val} items per page`);
  }

  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
  }

  /** 多选按钮变化事件 */
  function handleSelectionChange(val) {
    console.log("handleSelectionChange", val);
    selectedNum.value = val.length;
  }


  /**
   * 升级包反馈搜索
   */
  async function onSearch() {
    loading.value = true;
    console.log(toRaw(form))
    let new_form = {
      feedBackType: 0,
      feedBackTime: "",
      status: 0,
      tableId: tableId.value,
    }
    form.status == '0' ? new_form.status = 0 : new_form.status = 1;
    new_form.feedBackType == parseInt(form.feedBackType);
    new_form.feedBackTime = form.feedBackTime;
    const { data } = await getFeedbackList(new_form);
    dataList.value = data.list;
    pagination.total = data.total;
    pagination.pageSize = data.pageSize;
    pagination.currentPage = data.currentPage;

    setTimeout(() => {
      loading.value = false;
    }, 500);
  }

  const resetForm = formEl => {
    if (!formEl) return;
    formEl.resetFields();
    onSearch();
  };

  function openDialog(title = "新增", row?: FormItemProps) {
    addDialog({
      title: `${title}角色`,
      props: {
        formInline: {
          feedBackId: row?.feedBackId ?? "",
          feedBackType: row?.feedBackType ?? 0,
          feedBackTitle: row?.feedBackTitle ?? "",
          nickname: row?.nickname ?? "",
          userId: row?.userId ?? 0,
          headshot: row?.headshot ?? "",
          packageId: row?.feedBackId ?? "",
          packageName: row?.packageName ?? "",
          packageVersion: row?.packageVersion ?? "",
          feedBackTime: row?.feedBackTime ?? "",
          status: row?.status ?? 0,
          feedBackContent: row?.feedBackContent ?? "",
        }
      },
      width: "70%",
      draggable: true,
      fullscreen: deviceDetection(),
      fullscreenIcon: true,
      closeOnClickModal: false,
      contentRenderer: () => h(editForm, { ref: formRef }),
      beforeSure: (done, { options }) => {
        const FormRef = formRef.value.getRef();
        const curData = options.props.formInline as FormItemProps;
        function chores() {
          message(`您${title}了角色名称为${curData.name}的这条数据`, {
            type: "success"
          });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        FormRef.validate(valid => {
          if (valid) {
            console.log("curData", curData);
            // 表单规则校验通过
            if (title === "新增") {
              // 实际开发先调用新增接口，再进行下面操作
              chores();
            } else {
              // 实际开发先调用修改接口，再进行下面操作
              chores();
            }
          }
        });
      }
    });
  }
  
  /** 取消选择 */
  function onSelectionCancel() {
    selectedNum.value = 0;
    // 用于多选表格，清空用户的选择
    tableRef.value.getTableRef().clearSelection();
  }


  /** 高亮当前权限选中行 */
  function rowStyle({ row: { id } }) {
    return {
      cursor: "pointer",
      background: id === curRow.value?.id ? "var(--el-fill-color-light)" : ""
    };
  }


  const tableId = ref();

  async function getTableId(tId) {
    console.log("tableId赋值")
    tableId.value = tId;
    console.log(tId)
  }

  /** 数据权限 可自行开发 */
  // function handleDatabase() {}

  const onQueryChanged = (query: string) => {
    treeRef.value!.filter(query);
  };

  const filterMethod = (query: string, node) => {
    return transformI18n(node.title)!.includes(query);
  };

  watch(isExpandAll, val => {
    val
      ? treeRef.value.setExpandedKeys(treeIds.value)
      : treeRef.value.setExpandedKeys([]);
  });

  watch(isSelectAll, val => {
    val
      ? treeRef.value.setCheckedKeys(treeIds.value)
      : treeRef.value.setCheckedKeys([]);
  });

  return {
    form,
    isShow,
    curRow,
    loading,
    columns,
    rowStyle,
    dataList,
    treeData,
    treeProps,
    isLinkage,
    pagination,
    isExpandAll,
    isSelectAll,
    treeSearchValue,
    // buttonClass,
    onSearch,
    resetForm,
    openDialog,
    selectedNum,
    filterMethod,
    transformI18n,
    onQueryChanged,
    // handleDatabase,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    getTableId,
    onSelectionCancel,
    onbatchDel,
  };
}
