import dayjs from "dayjs";
import editForm from "../form.vue";
import tableForm from "../tableForm.vue";
import { handleTree } from "@/utils/tree";
import { message } from "@/utils/message";
import { ElMessageBox } from "element-plus";
import { usePublicHooks } from "../hooks";
import { transformI18n } from "@/plugins/i18n";
import { addDialog } from "@/components/ReDialog";
import type { FormItemProps } from "../utils/types";
import type { PaginationProps } from "@pureadmin/table";
import { getKeyList, deviceDetection, createFormData } from "@pureadmin/utils";
import { getRoleList, getRoleMenu, getRoleMenuIds } from "@/api/system";
import { type Ref, reactive, ref, onMounted, h, toRaw, watch } from "vue";
import { addformUpload, alterformUpload, deleteUpgradePackage, getAllUpgradePackage, } from "@/api/upgradePackage";
import { alterUpgradePackageTableDescriptionById } from "@/api/upgradePackageTable";
import { useUserStoreHook } from "@/store/modules/user";
const tableId = ref();
export function useRole(treeRef: Ref) {
  const form = reactive({
    packageName: "",
    packageVersion: "",
    createTime: 0,
  });
  const getPackageType = (type, text = false) => {
    switch (type) {
      case 0:
        return text ? "全量更新包" : "danger";
      case 1:
        return text ? "增量更新包" : "warning";
      case 2:
        return text ? "补丁包" : "info";
      case 3:
        return text ? "安全更新包" : "success";
      case 4:
        return text ? "功能更新包" : "primary";
      case 5:
        return text ? "回滚包" : "default";
    }
  };
  const getSystemType = (type, text = false) => {
    switch (type) {
      case 0:
        return text ? "64位" : "success";
      case 1:
        return text ? "32位" : "primary";
    }
  };
  const curRow = ref();
  const formRef = ref();
  const dataList = ref([]);
  const treeIds = ref([]);
  const treeData = ref([]);
  const isShow = ref(false);
  const loading = ref(true);
  const isLinkage = ref(false);
  const treeSearchValue = ref();
  const switchLoadMap = ref({});
  const isExpandAll = ref(false);
  const isSelectAll = ref(false);
  const { switchStyle } = usePublicHooks();
  const treeProps = {
    value: "id",
    label: "title",
    children: "children"
  };
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  const columns: TableColumnList = [
    {
      label: "升级包编号",
      prop: "packageId"
    },
    {
      label: "升级包名字",
      prop: "packageName"
    },
    {
      label: "升级包类型",
      prop: "packageType",
      cellRenderer: ({ row, props }) => (
        <el-tag
          size={props.size}
          type={getPackageType(parseInt(row.packageType))}
          effect="plain"
        >
          {getPackageType(parseInt(row.packageType), true)}
        </el-tag>
      )
    },
    {
      label: "升级包版本",
      prop: "packageVersion"
    },
    {
      label: "适应操作系统",
      prop: "systemType",
      cellRenderer: ({ row, props }) => (
        <el-tag
          size={props.size}
          type={getSystemType(parseInt(row.systemType))}
          effect="plain"
        >
          {getSystemType(parseInt(row.systemType), true)}
        </el-tag>
      )
    },
    {
      label: "升级包大小",
      prop: "packageSize"
    },
    {
      label: "升级包下载次数",
      prop: "pageDownload"
    },
    {
      label: "发布者",
      prop: "operator"
    },
    {
      label: "状态",
      cellRenderer: scope => (
        <el-switch
          size={scope.props.size === "small" ? "small" : "default"}
          loading={switchLoadMap.value[scope.index]?.loading}
          v-model={scope.row.status}
          active-value={1}
          inactive-value={0}
          active-text="已启用"
          inactive-text="已停用"
          inline-prompt
          style={switchStyle.value}
          onChange={() => onChange(scope as any)}
        />
      ),
      minWidth: 90
    },
    {
      label: "升级包创建时间",
      prop: "createTime",
      minWidth: 160,
      formatter: ({ createTime }) =>
        dayjs(createTime).format("YYYY-MM-DD HH:mm:ss")
    },
    {
      label: "操作",
      fixed: "right",
      width: 210,
      slot: "operation"
    }
  ];
  // const buttonClass = computed(() => {
  //   return [
  //     "!h-[20px]",
  //     "reset-margin",
  //     "!text-gray-500",
  //     "dark:!text-white",
  //     "dark:hover:!text-primary"
  //   ];
  // });
  async function getTableId(tId) {
    console.log("tableId赋值")
    tableId.value = tId;
    console.log(tId)
  }
  function onChange({ row, index }) {
    ElMessageBox.confirm(
      `确认要<strong>${row.status === 0 ? "停用" : "启用"
      }</strong><strong style='color:var(--el-color-primary)'>${row.name
      }</strong>吗?`,
      "系统提示",
      {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
        dangerouslyUseHTMLString: true,
        draggable: true
      }
    )
      .then(() => {
        switchLoadMap.value[index] = Object.assign(
          {},
          switchLoadMap.value[index],
          {
            loading: true
          }
        );
        setTimeout(() => {
          switchLoadMap.value[index] = Object.assign(
            {},
            switchLoadMap.value[index],
            {
              loading: false
            }
          );
          message(`已${row.status === 0 ? "停用" : "启用"}${row.name}`, {
            type: "success"
          });
        }, 300);
      })
      .catch(() => {
        row.status === 0 ? (row.status = 1) : (row.status = 0);
      });
  }
  /**
   * 单删
   * @param row 删除的行数据 
   */
  function handleDelete(row) {
    deleteUpgradePackage({ packageId: row.packageId,tableId: tableId.value }).then(res => {
      if (res.success) {
        message(`您删除了角色名称为${row.name}的这条数据`, { type: "success" });
        onSearch();
      } else {
        message('删除升级包失败', { type: "error" })
      }
    })
  }

  function handleSizeChange(val: number) {
    console.log(`${val} items per page`);
  }

  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
  }

  function handleSelectionChange(val) {
    console.log("handleSelectionChange", val);
  }
  /**
   * 获取升级包
   */
  async function onSearch() {
    loading.value = true;
    let selectForm = {
      tableId: 0,
      packageName: "",
      packageVersion: "",
      createTime: 0,
    }
    selectForm = Object.assign(form);
    selectForm.tableId = tableId.value;
    console.log("升级包查询`")
    console.log(selectForm)
    const { data } = await getAllUpgradePackage(selectForm);
    dataList.value = data.list;
    pagination.total = data.total;
    pagination.pageSize = data.pageSize;
    pagination.currentPage = data.currentPage;

    setTimeout(() => {
      loading.value = false;
    }, 500);
  }

  const resetForm = formEl => {
    if (!formEl) return;
    formEl.resetFields();
    onSearch();
  };

  function openTableDialog(row?: any) {
    addDialog({
      title: "修改升级包主页备注",
      props: {
        formInline: {
          tableId: tableId.value,
        }
      },
      width: "60%",
      draggable: true,
      fullscreen: deviceDetection(),
      fullscreenIcon: true,
      closeOnClickModal: false,
      contentRenderer: () => h(tableForm, { ref: formRef }),
      beforeSure: (done, { options }) => {
        const FormRef = formRef.value.getRef();
        const curData = options.props.formInline as FormItemProps;
                function chores() {
          message(`您修改了该升级包说明`, {
            type: "success"
          });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        FormRef.validate(async valid => {
          if (valid) {
            await formRef.value.edit.synInforMation();
            console.log("curData", curData.os);
            alterUpgradePackageTableDescriptionById({tableId: tableId.value, description: curData.os }).then(res => {
              if (res.success) {
                chores();
              } else {
                message("修改升级包说明失败",{type:"error"})
              }
            })
          } else {
            message("输入不符合规范!",{type:"error"})
          }
        });
      }
    })

  }

  /** 新增和修改升级包 */

  function openDialog(title = "新增", row?: FormItemProps) {
    console.log(row.fileList)
    addDialog({
      title: `${title}升级包`,
      props: {
        formInline: {
          packageId: row?.packageId ?? 0,
          packageName: row?.packageName ?? "",
          packageType: row?.packageType ?? "",
          packageVersion: row?.packageVersion ?? "",
          operator: row?.operator ?? "",
          systemType: 0,
          status: 1,
          os: row?.os ?? "",
          fileList: row?.fileList ?? [],
          ossPath: row?.ossPath ?? "",
          fileName: row?.fileName ?? "",
        }
      },
      width: "60%",
      draggable: true,
      fullscreen: deviceDetection(),
      fullscreenIcon: true,
      closeOnClickModal: false,
      contentRenderer: () => h(editForm, { ref: formRef }),
      beforeSure: (done, { options }) => {
        const FormRef = formRef.value.getRef();
        const curData = options.props.formInline as FormItemProps;
        function chores() {
          message(`您${title}了升级包名称为${curData.packageName}的这条数据`, {
            type: "success"
          });
          done(); // 关闭弹框
          onSearch(); // 刷新表格数据
        }
        FormRef.validate(async valid => {
          if (valid) {
            await formRef.value.edit.synInforMation();
            // 表单规则校验通过
            if (title === "新增") {
              // 单独处理文件上传
              const op = useUserStoreHook().ID;
              const formData = createFormData({
                files: curData.fileList.map(file => ({ raw: file.raw })), // file 文件
                fields: {
                  packageId: curData.packageId,
                  packageName: curData.packageName,
                  packageType: curData.packageType,
                  packageVersion: curData.packageVersion,
                  adminId: op,
                  systemType: curData.systemType,
                  status: curData.status,
                  os: curData.os,
                },
                tableId: tableId.value
              });
              addformUpload(formData)
                .then(({ success }) => {
                  if (success) {
                    chores();
                  } else {
                    message("升级包创建失败", { type: "error" });
                  }
                })
                .catch(error => {
                  message(`上传异常 ${error}`, { type: "error" });
                });
              
            } else {
              // 处理一下文件列表筛选出新增的文件
              const newFileList = curData.fileList.filter(file => file.raw != undefined);
              // 处理一下展示的文件
              const showFileList = curData.fileList.filter(file => file.raw == undefined);
              // 删除的文件为row原有文件列表减去展示的文件列表
              const deleteFileList = ref([]);
              if (showFileList.length == 0) {
                deleteFileList.value = showFileList;
              }
              const formData = createFormData({
                files: newFileList.map(file => ({ raw: file.raw?file.raw:null })), // file 文件
                fields: {
                  packageId: curData.packageId,
                  packageName: curData.packageName,
                  packageType: curData.packageType,
                  packageVersion: curData.packageVersion,
                  systemType: curData.systemType,
                  status: curData.status,
                  os: curData.os,
                },
                deleteFileList: deleteFileList.value,//用户删除的文件
                tableId: tableId.value,
              });
              console.log({
                files: newFileList.map(file => ({ raw: file.raw })), // file 文件
                fields: {
                  packageId: curData.packageId,
                  packageName: curData.packageName,
                  packageType: curData.packageType,
                  packageVersion: curData.packageVersion,
                  systemType: curData.systemType,
                  status: curData.status,
                  os: curData.os,
                },
                deleteFileList: deleteFileList.value,//用户删除的文件
                tableId: tableId.value,
              })
              // alterformUpload(formData)
              //   .then(({ success }) => {
              //     if (success) {
              //       chores();
              //       chores();
              //     } else {
              //       message("升级包失败", { type: "error" });
              //     }
              //   })
              //   .catch(error => {
              //     message(`上传异常 ${error}`, { type: "error" });
              //   });
            }
          }
        });
      }
    });
  }

  /** 菜单权限 */
  async function handleMenu(row?: any) {
    const { id } = row;
    if (id) {
      curRow.value = row;
      isShow.value = true;
      const { data } = await getRoleMenuIds({ id });
      treeRef.value.setCheckedKeys(data);
    } else {
      curRow.value = null;
      isShow.value = false;
    }
  }

  /** 高亮当前权限选中行 */
  function rowStyle({ row: { id } }) {
    return {
      cursor: "pointer",
      background: id === curRow.value?.id ? "var(--el-fill-color-light)" : ""
    };
  }

  /** 菜单权限-保存 */
  function handleSave() {
    const { id, name } = curRow.value;
    // 根据用户 id 调用实际项目中菜单权限修改接口
    console.log(id, treeRef.value.getCheckedKeys());
    message(`角色名称为${name}的菜单权限修改成功`, {
      type: "success"
    });
  }

  /** 数据权限 可自行开发 */
  // function handleDatabase() {}

  const onQueryChanged = (query: string) => {
    treeRef.value!.filter(query);
  };

  const filterMethod = (query: string, node) => {
    return transformI18n(node.title)!.includes(query);
  };


  watch(isExpandAll, val => {
    val
      ? treeRef.value.setExpandedKeys(treeIds.value)
      : treeRef.value.setExpandedKeys([]);
  });

  watch(isSelectAll, val => {
    val
      ? treeRef.value.setCheckedKeys(treeIds.value)
      : treeRef.value.setCheckedKeys([]);
  });
  return {
    form,
    isShow,
    curRow,
    loading,
    columns,
    rowStyle,
    dataList,
    treeData,
    treeProps,
    isLinkage,
    pagination,
    isExpandAll,
    isSelectAll,
    treeSearchValue,
    // buttonClass,
    onSearch,
    resetForm,
    openDialog,
    handleMenu,
    handleSave,
    handleDelete,
    filterMethod,
    transformI18n,
    onQueryChanged,
    // handleDatabase,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    getTableId,
    openTableDialog
  };
}
