import { delay } from "@pureadmin/utils";
import { ref, onMounted, reactive } from "vue";
import type { PaginationProps } from "@pureadmin/table";
import ThumbUp from "@iconify-icons/ri/thumb-up-line";
import Hearts from "@iconify-icons/ri/hearts-line";
import Empty from "./empty.svg?component";

export function useColumns() {
  const dataList = ref([]);
  const loading = ref(true);
  const columns: TableColumnList = [
    {
      sortable: true,
      label: "序号",
      prop: "packageId"
    },
    {
      sortable: true,
      label: "升级包名称",
      prop: "packageName",
      filterMultiple: false,
      filterClassName: "pure-table-filter",
      filters: [
        { text: "≥16000", value: "more" },
        { text: "<16000", value: "less" }
      ],
      filterMethod: (value, { tableName }) => {
        return value === "more"
          ? tableName >= 16000
          : tableName < 16000;
      }
    },
    {
      sortable: true,
      label: "版本号",
      prop: "packageVersion"
    },
    {
      sortable: true,
      label: "文件大小",
      prop: "packageSize"
    },
    {
      sortable: true,
      label: "发布日期",
      minWidth: 100,
      prop: "createTime",
    },
    {
      sortable: true,
      label: "状态",
      prop: "status",
      cellRenderer: ({ row, props }) => (
        <el-tag
          size={props.size}
          type={getPackageStatus(row.status)}
          effect="plain"
        >
          {getPackageStatus(row.status, true)}
        </el-tag>
      )
    },
    {
      label: "查看",
      fixed: "right",
      slot: "operation"
    }
  ];

    const getPackageStatus = (type, text = false) => {
    switch (type) {
      case 0:
        return text ? "最新版本" : "success";
      case 1:
        return text ? "有新版本" : "primary";
      case 2:
        return text ? "更新中" : "warning";
      case 3:
        return text?  "失败": "danger";
    }
  };
  /** 分页配置 */
  const pagination = reactive<PaginationProps>({
    pageSize: 10,
    currentPage: 1,
    layout: "prev, pager, next",
    total: 0,
    align: "center"
  });

  function onCurrentChange(page: number) {
    console.log("onCurrentChange", page);
    loading.value = true;
    delay(300).then(() => {
      loading.value = false;
    });
  }
  // 已安装升级包列表
  const tableData = ref([
    {
      packageId: 1,
      packageName: "升级包1",
      packageVersion: "1.0.0",
      packageSize: "10M",
      createTime: "2021-08-01",
      status: 0
    },
    {
      packageId: 2,
      packageName: "升级包2",
      packageVersion: "1.0.0",
      packageSize: "10M",
      createTime: "2021-08-01",
      status: 0
    },
    {
      packageId: 3,
      packageName: "升级包3",
      packageVersion: "1.0.0",
      packageSize: "10M",
      createTime: "2021-08-01",
      status: 0
    },
    {
      packageId: 4,
      packageName: "升级包4",
      packageVersion: "1.0.0",
      packageSize: "10M",
      createTime: "2021-08-01",
      status: 1
    },
    {
      packageId: 5,
      packageName: "升级包5",
      packageVersion: "1.0.0",
      packageSize: "10M",
      createTime: "2021-08-01",
      status: 2
    }
  ]);

  onMounted(() => {
    dataList.value = tableData.value;
    pagination.total = dataList.value.length;
    loading.value = false;
  });

  return {
    Empty,
    loading,
    columns,
    dataList,
    pagination,
    onCurrentChange
  };
}
