import { tableData } from "../../data";
import { delay } from "@pureadmin/utils";
import { ref, onMounted, reactive } from "vue";
import type { PaginationProps } from "@pureadmin/table";
import ThumbUp from "@iconify-icons/ri/thumb-up-line";
import Hearts from "@iconify-icons/ri/hearts-line";
import Empty from "./empty.svg?component";

export function useColumns() {
  const dataList = ref([]);
  const loading = ref(true);
  const columns: TableColumnList = [
    {
      sortable: true,
      label: "序号",
      prop: "tableId"
    },
    {
      sortable: true,
      label: "升级包名称",
      prop: "tableName",
      filterMultiple: false,
      filterClassName: "pure-table-filter",
      filters: [
        { text: "≥16000", value: "more" },
        { text: "<16000", value: "less" }
      ],
      filterMethod: (value, { tableName }) => {
        return value === "more"
          ? tableName >= 16000
          : tableName < 16000;
      }
    },
    {
      sortable: true,
      label: "下载数量",
      prop: "tableDonwloadNum"
    },
    {
      sortable: true,
      label: "反馈数量",
      prop: "tableFeedbackNum"
    },
    {
      sortable: true,
      label: "反馈解决数",
      minWidth: 100,
      prop: "tableFeedbackSolvedNum",
    },
    {
      sortable: true,
      label: "安装成功数",
      prop: "tableInstallNum"
    },
    {
      label: "操作",
      fixed: "right",
      slot: "operation"
    }
  ];

  /** 分页配置 */
  const pagination = reactive<PaginationProps>({
    pageSize: 10,
    currentPage: 1,
    layout: "prev, pager, next",
    total: 0,
    align: "center"
  });

  function onCurrentChange(page: number) {
    console.log("onCurrentChange", page);
    loading.value = true;
    delay(300).then(() => {
      loading.value = false;
    });
  }

  onMounted(() => {
    dataList.value = tableData.value;
    pagination.total = dataList.value.length;
    loading.value = false;
  });

  return {
    Empty,
    loading,
    columns,
    dataList,
    pagination,
    onCurrentChange
  };
}
